@@ -70,25 +70,25 @@ class BenchmarkDBResource(object):
             command = "SELECT * FROM {}".format(real_time_table_name)
         else:
             command = "SELECT * FROM {} WHERE `index`>{}".format(real_time_table_name, real_timi_mini_index)
-        results = self.execute_sql_command(command)
+        results = self.sql.execute_sql_command(command)
         results_dict = [{"index":item[0], "time":item[6], "read_iops": item[1], "read_bw":item[2], "write_iops":item[3],
                          "write_bw":item[4], "temperature": item[5]} for item in results]
         return results_dict
 
-    def execute_sql_command(self, command):
-        results = list()
-        try:
-            self.sql.cursor.execute(command)
-            results = self.sql.cursor.fetchall()
-        except BaseException as message:
-            print(message)
-        return results
+    # def execute_sql_command(self, command):
+    #     results = list()
+    #     try:
+    #         self.sql.cursor.execute(command)
+    #         results = self.sql.cursor.fetchall()
+    #     except BaseException as message:
+    #         print(message)
+    #     return results
 
     def get_test_config(self, index):
         results_dict = dict()
         config_index = self.get_spec_index(index, "config_index")
         command = "SELECT * FROM _configuration WHERE `index`={}".format(config_index)
-        results = self.execute_sql_command(command)
+        results = self.sql.execute_sql_command(command)
         if results:
             results_dict = {
                 "type": results[0][1],
@@ -107,7 +107,7 @@ class BenchmarkDBResource(object):
         results_dict = dict()
         env_index = self.get_spec_index(index, "test_env_index")
         command = "SELECT * FROM _environment WHERE `index`={}".format(env_index)
-        results = self.execute_sql_command(command)
+        results = self.sql.execute_sql_command(command)
         if results:
             results_dict = {
                 "vendor": results[0][1],
@@ -124,12 +124,15 @@ class BenchmarkDBResource(object):
         result_dict = dict()
         report_index = self.get_spec_index(index, "summary_report_index")
         command = "SELECT * FROM _summary_test_results WHERE `index`={}".format(report_index)
-        results = self.execute_sql_command(command)
+        results = self.sql.execute_sql_command(command)
         if results:
             result_dict = {"iops_read":results[0][1],
                            "bw_read":results[0][2],
                            "io_read":results[0][3],
                            "avg_latency_read":results[0][4],
+                           "max_latency_read": results[0][22],
+                           "min_latency_read": results[0][23],
+                           "percent_99_read": results[0][26],
                            "percent_999_read": results[0][5],
                            "percent_9999_read": results[0][6],
                            "percent_99999_read": results[0][7],
@@ -140,6 +143,9 @@ class BenchmarkDBResource(object):
                            "bw_write": results[0][12],
                            "io_write": results[0][13],
                            "avg_latency_write": results[0][14],
+                           "max_latency_write": results[0][24],
+                           "min_latency_write": results[0][25],
+                           "percent_99_write": results[0][27],
                            "percent_999_write": results[0][15],
                            "percent_9999_write": results[0][16],
                            "percent_99999_write": results[0][17],
@@ -158,7 +164,7 @@ class BenchmarkDBResource(object):
     def get_test_state(self, index):
         result = None
         command = "SELECT state FROM _tests WHERE `index`={}".format(index)
-        results = self.execute_sql_command(command)
+        results = self.sql.execute_sql_command(command)
         if results:
             result = results[0][0]
         return result
@@ -166,19 +172,24 @@ class BenchmarkDBResource(object):
     def get_index_by_key(self, key):
         result = None
         command = "SELECT `index` FROM _tests WHERE `key`='{}'".format(key)
-        results = self.execute_sql_command(command)
+        results = self.sql.execute_sql_command(command)
         if results:
             result = results[0][0]
         return result
 
     def search_tests_by_group_key(self, group_key):
         sea_string = "SELECT * FROM _tests WHERE group_key='{}'".format(group_key)
-        result = self.execute_sql_command(sea_string)
+        result = self.sql.execute_sql_command(sea_string)
+        return result
+
+    def search_test_name(self, test_name):
+        sea_string = "SELECT * FROM _tests WHERE group_name='{}'".format(test_name)
+        result = self.sql.execute_sql_command(sea_string)
         return result
 
     def search_step_by_key(self, step_key):
         sea_string = "SELECT * FROM _tests WHERE `key`='{}'".format(step_key)
-        result = self.execute_sql_command(sea_string)
+        result = self.sql.execute_sql_command(sea_string)
         return result
 
     def confirm_test(self, step_key):
