@@ -24,3 +24,12 @@ class SqlConnection(object):
         self.cursor.execute(cmd)
         result = self.cursor.fetchone()
         return result
+
+    def execute_sql_command(self, command):
+        results = list()
+        try:
+            self.cursor.execute(command)
+            results = self.cursor.fetchall()
+        except BaseException as message:
+            print(message)
+        return results
\ No newline at end of file
